// Generated by gmmproc 2.75.0 -- DO NOT MODIFY!
#ifndef _GTKMM_SORTER_P_H
#define _GTKMM_SORTER_P_H


#include <glibmm/private/object_p.h>

#include <glibmm/class.h>

namespace Gtk
{

class GTKMM_API Sorter_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  using CppObjectType = Sorter;
  using BaseObjectType = GtkSorter;
  using BaseClassType = GtkSorterClass;
  using CppClassParent = Glib::Object_Class;
  using BaseClassParent = GObjectClass;

  friend class Sorter;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();


  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.

  //Callbacks (virtual functions):
  static GtkOrdering compare_vfunc_callback(GtkSorter* self, gpointer item1, gpointer item2);
  static GtkSorterOrder get_order_vfunc_callback(GtkSorter* self);
};


} // namespace Gtk


#endif /* _GTKMM_SORTER_P_H */

