// Generated by gmmproc 2.75.0 -- DO NOT MODIFY!


#include <glibmm.h>

#include <gtkmm/selectionfiltermodel.h>
#include <gtkmm/private/selectionfiltermodel_p.h>


/* Copyright (C) 2020 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>

namespace
{
} // anonymous namespace


namespace Glib
{

Glib::RefPtr<Gtk::SelectionFilterModel> wrap(GtkSelectionFilterModel* object, bool take_copy)
{
  return Glib::make_refptr_for_instance<Gtk::SelectionFilterModel>( dynamic_cast<Gtk::SelectionFilterModel*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gtk
{


/* The *_Class implementation: */

const Glib::Class& SelectionFilterModel_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &SelectionFilterModel_Class::class_init_function;

    // Do not derive a GType, or use a derived class:
    gtype_ = gtk_selection_filter_model_get_type();

  }

  return *this;
}


void SelectionFilterModel_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* SelectionFilterModel_Class::wrap_new(GObject* object)
{
  return new SelectionFilterModel((GtkSelectionFilterModel*)object);
}


/* The implementation: */

GtkSelectionFilterModel* SelectionFilterModel::gobj_copy()
{
  reference();
  return gobj();
}

SelectionFilterModel::SelectionFilterModel(const Glib::ConstructParams& construct_params)
:
  Glib::Object(construct_params)
{

}

SelectionFilterModel::SelectionFilterModel(GtkSelectionFilterModel* castitem)
:
  Glib::Object((GObject*)(castitem))
{}


SelectionFilterModel::SelectionFilterModel(SelectionFilterModel&& src) noexcept
: Glib::Object(std::move(src))
  , Gio::ListModel(std::move(src))
{}

SelectionFilterModel& SelectionFilterModel::operator=(SelectionFilterModel&& src) noexcept
{
  Glib::Object::operator=(std::move(src));
  Gio::ListModel::operator=(std::move(src));
  return *this;
}


SelectionFilterModel::~SelectionFilterModel() noexcept
{}


SelectionFilterModel::CppClassType SelectionFilterModel::selectionfiltermodel_class_; // initialize static member

GType SelectionFilterModel::get_type()
{
  return selectionfiltermodel_class_.init().get_type();
}


GType SelectionFilterModel::get_base_type()
{
  return gtk_selection_filter_model_get_type();
}


SelectionFilterModel::SelectionFilterModel(const Glib::RefPtr<SelectionModel>& model)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Glib::Object(Glib::ConstructParams(selectionfiltermodel_class_.init(), "model", Glib::unwrap(model), nullptr))
{
  

}

Glib::RefPtr<SelectionFilterModel> SelectionFilterModel::create(const Glib::RefPtr<SelectionModel>& model)
{
  return Glib::make_refptr_for_instance<SelectionFilterModel>( new SelectionFilterModel(model) );
}

void SelectionFilterModel::set_model(const Glib::RefPtr<SelectionModel>& model)
{
  gtk_selection_filter_model_set_model(gobj(), Glib::unwrap(model));
}

Glib::RefPtr<SelectionModel> SelectionFilterModel::get_model()
{
  auto retvalue = Glib::wrap(gtk_selection_filter_model_get_model(gobj()));
  if(retvalue)
    retvalue->reference(); //The function does not do a ref for us.
  return retvalue;
}

Glib::RefPtr<const SelectionModel> SelectionFilterModel::get_model() const
{
  return const_cast<SelectionFilterModel*>(this)->get_model();
}


static_assert(Glib::Traits::ValueCompatibleWithWrapProperty<GType>::value,
  "Type GType cannot be used in _WRAP_PROPERTY. "
  "There is no suitable template specialization of Glib::Value<>.");

Glib::PropertyProxy_ReadOnly< GType > SelectionFilterModel::property_item_type() const
{
  return Glib::PropertyProxy_ReadOnly< GType >(this, "item-type");
}

static_assert(Glib::Traits::ValueCompatibleWithWrapProperty<Glib::RefPtr<SelectionModel>>::value,
  "Type Glib::RefPtr<SelectionModel> cannot be used in _WRAP_PROPERTY. "
  "There is no suitable template specialization of Glib::Value<>.");

Glib::PropertyProxy< Glib::RefPtr<SelectionModel> > SelectionFilterModel::property_model() 
{
  return Glib::PropertyProxy< Glib::RefPtr<SelectionModel> >(this, "model");
}

Glib::PropertyProxy_ReadOnly< Glib::RefPtr<SelectionModel> > SelectionFilterModel::property_model() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::RefPtr<SelectionModel> >(this, "model");
}

Glib::PropertyProxy_ReadOnly< unsigned int > SelectionFilterModel::property_n_items() const
{
  return Glib::PropertyProxy_ReadOnly< unsigned int >(this, "n-items");
}


} // namespace Gtk


